@@ -9,15 +9,21 @@ types: list[str] = [
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
+    "AWS::AmazonMQ::Broker",
+    "AWS::AmazonMQ::Configuration",
+    "AWS::AmazonMQ::ConfigurationAssociation",
     "AWS::ApiGateway::Account",
     "AWS::ApiGateway::ApiKey",
     "AWS::ApiGateway::Authorizer",
     "AWS::ApiGateway::BasePathMapping",
+    "AWS::ApiGateway::BasePathMappingV2",
     "AWS::ApiGateway::ClientCertificate",
     "AWS::ApiGateway::Deployment",
     "AWS::ApiGateway::DocumentationPart",
     "AWS::ApiGateway::DocumentationVersion",
     "AWS::ApiGateway::DomainName",
+    "AWS::ApiGateway::DomainNameAccessAssociation",
+    "AWS::ApiGateway::DomainNameV2",
     "AWS::ApiGateway::GatewayResponse",
     "AWS::ApiGateway::Method",
     "AWS::ApiGateway::Model",
@@ -48,12 +54,16 @@ types: list[str] = [
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
     "AWS::Batch::ComputeEnvironment",
+    "AWS::Batch::ConsumableResource",
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
     "AWS::CDK::Metadata",
     "AWS::CertificateManager::Certificate",
     "AWS::CloudFormation::CustomResource",
+    "AWS::CloudFormation::HookDefaultVersion",
+    "AWS::CloudFormation::HookTypeConfig",
+    "AWS::CloudFormation::HookVersion",
     "AWS::CloudFormation::Macro",
     "AWS::CloudFormation::ResourceDefaultVersion",
     "AWS::CloudFormation::ResourceVersion",
@@ -86,9 +96,12 @@ types: list[str] = [
     "AWS::CodeDeploy::DeploymentGroup",
     "AWS::CodePipeline::CustomActionType",
     "AWS::CodePipeline::Pipeline",
+    "AWS::Config::AggregationAuthorization",
     "AWS::Config::ConfigRule",
+    "AWS::Config::ConfigurationAggregator",
     "AWS::Config::ConfigurationRecorder",
     "AWS::Config::DeliveryChannel",
+    "AWS::Config::StoredQuery",
     "AWS::DLM::LifecyclePolicy",
     "AWS::DataPipeline::Pipeline",
     "AWS::DataSync::Agent",
@@ -147,6 +160,7 @@ types: list[str] = [
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
     "AWS::EC2::TransitGatewayMulticastGroupSource",
+    "AWS::EC2::TransitGatewayPeeringAttachment",
     "AWS::EC2::TransitGatewayRoute",
     "AWS::EC2::TransitGatewayRouteTable",
     "AWS::EC2::TransitGatewayRouteTableAssociation",
@@ -200,6 +214,7 @@ types: list[str] = [
     "AWS::ElastiCache::ReplicationGroup",
     "AWS::ElastiCache::SecurityGroup",
     "AWS::ElastiCache::SecurityGroupIngress",
+    "AWS::ElastiCache::ServerlessCache",
     "AWS::ElastiCache::SubnetGroup",
     "AWS::ElastiCache::User",
     "AWS::ElastiCache::UserGroup",
@@ -218,9 +233,33 @@ types: list[str] = [
     "AWS::Elasticsearch::Domain",
     "AWS::Events::EventBus",
     "AWS::Events::Rule",
+    "AWS::FMS::NotificationChannel",
+    "AWS::FMS::Policy",
+    "AWS::FMS::ResourceSet",
     "AWS::GameLift::Alias",
     "AWS::GameLift::Build",
     "AWS::GameLift::Fleet",
+    "AWS::Glue::Classifier",
+    "AWS::Glue::Connection",
+    "AWS::Glue::Crawler",
+    "AWS::Glue::CustomEntityType",
+    "AWS::Glue::DataCatalogEncryptionSettings",
+    "AWS::Glue::DataQualityRuleset",
+    "AWS::Glue::Database",
+    "AWS::Glue::DevEndpoint",
+    "AWS::Glue::Job",
+    "AWS::Glue::MLTransform",
+    "AWS::Glue::Partition",
+    "AWS::Glue::SecurityConfiguration",
+    "AWS::Glue::Table",
+    "AWS::Glue::Trigger",
+    "AWS::Glue::Workflow",
+    "AWS::GuardDuty::Detector",
+    "AWS::GuardDuty::Filter",
+    "AWS::GuardDuty::MalwareProtectionPlan",
+    "AWS::GuardDuty::Master",
+    "AWS::GuardDuty::Member",
+    "AWS::GuardDuty::ThreatIntelSet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -256,7 +295,15 @@ types: list[str] = [
     "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
+    "AWS::KinesisAnalyticsV2::Application",
     "AWS::KinesisFirehose::DeliveryStream",
+    "AWS::LakeFormation::DataCellsFilter",
+    "AWS::LakeFormation::DataLakeSettings",
+    "AWS::LakeFormation::Permissions",
+    "AWS::LakeFormation::PrincipalPermissions",
+    "AWS::LakeFormation::Resource",
+    "AWS::LakeFormation::Tag",
+    "AWS::LakeFormation::TagAssociation",
     "AWS::Lambda::Alias",
     "AWS::Lambda::EventInvokeConfig",
     "AWS::Lambda::EventSourceMapping",
@@ -265,6 +312,9 @@ types: list[str] = [
     "AWS::Lambda::LayerVersionPermission",
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
+    "AWS::Logs::Delivery",
+    "AWS::Logs::DeliveryDestination",
+    "AWS::Logs::DeliverySource",
     "AWS::Logs::Destination",
     "AWS::Logs::LogGroup",
     "AWS::Logs::LogStream",
@@ -272,6 +322,11 @@ types: list[str] = [
     "AWS::Logs::QueryDefinition",
     "AWS::Logs::ResourcePolicy",
     "AWS::Logs::SubscriptionFilter",
+    "AWS::NetworkFirewall::Firewall",
+    "AWS::NetworkFirewall::FirewallPolicy",
+    "AWS::NetworkFirewall::LoggingConfiguration",
+    "AWS::NetworkFirewall::RuleGroup",
+    "AWS::NetworkFirewall::TLSInspectionConfiguration",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
     "AWS::OpenSearchService::Domain",
@@ -287,6 +342,7 @@ types: list[str] = [
     "AWS::Organizations::OrganizationalUnit",
     "AWS::Organizations::Policy",
     "AWS::Organizations::ResourcePolicy",
+    "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
     "AWS::RDS::DBClusterParameterGroup",
@@ -306,6 +362,7 @@ types: list[str] = [
     "AWS::Redshift::EndpointAccess",
     "AWS::Redshift::EndpointAuthorization",
     "AWS::Redshift::EventSubscription",
+    "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
     "AWS::RedshiftServerless::Workgroup",
@@ -317,8 +374,13 @@ types: list[str] = [
     "AWS::Route53::HostedZone",
     "AWS::Route53::RecordSet",
     "AWS::Route53::RecordSetGroup",
+    "AWS::Route53Resolver::FirewallDomainList",
+    "AWS::Route53Resolver::FirewallRuleGroup",
+    "AWS::Route53Resolver::FirewallRuleGroupAssociation",
     "AWS::Route53Resolver::ResolverConfig",
     "AWS::Route53Resolver::ResolverEndpoint",
+    "AWS::Route53Resolver::ResolverQueryLoggingConfig",
+    "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation",
     "AWS::Route53Resolver::ResolverRule",
     "AWS::Route53Resolver::ResolverRuleAssociation",
     "AWS::S3::AccessPoint",
@@ -342,10 +404,19 @@ types: list[str] = [
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
     "AWS::SSM::ResourceDataSync",
+    "AWS::SageMaker::Pipeline",
     "AWS::SecretsManager::ResourcePolicy",
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
     "AWS::SecretsManager::SecretTargetAttachment",
+    "AWS::SecurityHub::AutomationRule",
+    "AWS::SecurityHub::DelegatedAdmin",
+    "AWS::SecurityHub::Hub",
+    "AWS::SecurityHub::Insight",
+    "AWS::SecurityHub::OrganizationConfiguration",
+    "AWS::SecurityHub::ProductSubscription",
+    "AWS::SecurityHub::SecurityControl",
+    "AWS::SecurityHub::Standard",
     "AWS::ServiceDiscovery::HttpNamespace",
     "AWS::ServiceDiscovery::Instance",
     "AWS::ServiceDiscovery::PrivateDnsNamespace",
@@ -363,6 +434,12 @@ types: list[str] = [
     "AWS::WAF::SqlInjectionMatchSet",
     "AWS::WAF::WebACL",
     "AWS::WAF::XssMatchSet",
+    "AWS::WAFv2::IPSet",
+    "AWS::WAFv2::LoggingConfiguration",
+    "AWS::WAFv2::RegexPatternSet",
+    "AWS::WAFv2::RuleGroup",
+    "AWS::WAFv2::WebACL",
+    "AWS::WAFv2::WebACLAssociation",
     "AWS::WorkSpaces::Workspace",
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
@@ -378,19 +455,25 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-amazonmq-broker.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
     "aws-apigateway-basepathmapping.json",
+    "aws-apigateway-basepathmappingv2.json",
     "aws-apigateway-clientcertificate.json",
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainname.json",
+    "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -405,14 +488,19 @@ cached: list[str] = [
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-warmpool.json",
+    "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
     "aws-batch-computeenvironment.json",
+    "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-certificatemanager-certificate.json",
     "aws-cloudformation-customresource.json",
+    "aws-cloudformation-hookdefaultversion.json",
+    "aws-cloudformation-hooktypeconfig.json",
+    "aws-cloudformation-hookversion.json",
     "aws-cloudformation-macro.json",
     "aws-cloudformation-resourcedefaultversion.json",
     "aws-cloudformation-resourceversion.json",
@@ -422,6 +510,7 @@ cached: list[str] = [
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
+    "aws-cloudfront-distribution.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -437,8 +526,12 @@ cached: list[str] = [
     "aws-cloudwatch-compositealarm.json",
     "aws-cloudwatch-insightrule.json",
     "aws-codedeploy-deploymentgroup.json",
+    "aws-config-aggregationauthorization.json",
+    "aws-config-configrule.json",
+    "aws-config-configurationaggregator.json",
     "aws-config-configurationrecorder.json",
     "aws-config-deliverychannel.json",
+    "aws-config-storedquery.json",
     "aws-datasync-agent.json",
     "aws-datasync-locationazureblob.json",
     "aws-datasync-locationefs.json",
@@ -452,11 +545,14 @@ cached: list[str] = [
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
+    "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
+    "aws-ec2-eip.json",
     "aws-ec2-flowlog.json",
     "aws-ec2-gatewayroutetableassociation.json",
+    "aws-ec2-instance.json",
     "aws-ec2-internetgateway.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
@@ -464,6 +560,7 @@ cached: list[str] = [
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
     "aws-ec2-networkinterface.json",
+    "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-placementgroup.json",
     "aws-ec2-prefixlist.json",
     "aws-ec2-route.json",
@@ -475,6 +572,7 @@ cached: list[str] = [
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
+    "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
@@ -485,11 +583,13 @@ cached: list[str] = [
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
     "aws-ec2-transitgatewaymulticastgroupsource.json",
+    "aws-ec2-transitgatewaypeeringattachment.json",
     "aws-ec2-transitgatewayroute.json",
     "aws-ec2-transitgatewayroutetable.json",
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
     "aws-ec2-vpcblockpublicaccessoptions.json",
@@ -499,7 +599,11 @@ cached: list[str] = [
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
+    "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
+    "aws-ec2-vpnconnection.json",
+    "aws-ec2-vpnconnectionroute.json",
+    "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
@@ -526,13 +630,13 @@ cached: list[str] = [
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
+    "aws-elasticache-serverlesscache.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
     "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
-    "aws-elasticloadbalancingv2-loadbalancer.json",
     "aws-elasticloadbalancingv2-targetgroup.json",
     "aws-elasticloadbalancingv2-truststore.json",
     "aws-elasticloadbalancingv2-truststorerevocation.json",
@@ -542,6 +646,28 @@ cached: list[str] = [
     "aws-emr-instancegroupconfig.json",
     "aws-events-eventbus.json",
     "aws-events-rule.json",
+    "aws-fms-notificationchannel.json",
+    "aws-fms-policy.json",
+    "aws-fms-resourceset.json",
+    "aws-glue-classifier.json",
+    "aws-glue-connection.json",
+    "aws-glue-customentitytype.json",
+    "aws-glue-datacatalogencryptionsettings.json",
+    "aws-glue-dataqualityruleset.json",
+    "aws-glue-devendpoint.json",
+    "aws-glue-job.json",
+    "aws-glue-mltransform.json",
+    "aws-glue-partition.json",
+    "aws-glue-securityconfiguration.json",
+    "aws-glue-table.json",
+    "aws-glue-trigger.json",
+    "aws-glue-workflow.json",
+    "aws-guardduty-detector.json",
+    "aws-guardduty-filter.json",
+    "aws-guardduty-malwareprotectionplan.json",
+    "aws-guardduty-master.json",
+    "aws-guardduty-member.json",
+    "aws-guardduty-threatintelset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
@@ -566,16 +692,28 @@ cached: list[str] = [
     "aws-imagebuilder-workflow.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
+    "aws-lakeformation-datacellsfilter.json",
+    "aws-lakeformation-datalakesettings.json",
+    "aws-lakeformation-permissions.json",
+    "aws-lakeformation-principalpermissions.json",
+    "aws-lakeformation-resource.json",
+    "aws-lakeformation-tag.json",
+    "aws-lakeformation-tagassociation.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
+    "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
+    "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
+    "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
@@ -583,6 +721,11 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
+    "aws-networkfirewall-firewall.json",
+    "aws-networkfirewall-firewallpolicy.json",
+    "aws-networkfirewall-loggingconfiguration.json",
+    "aws-networkfirewall-rulegroup.json",
+    "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
     "aws-opensearchservice-domain.json",
@@ -595,6 +738,8 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-ram-permission.json",
+    "aws-ram-resourceshare.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
@@ -603,16 +748,13 @@ cached: list[str] = [
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
-    "aws-rds-globalcluster.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
-    "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
-    "aws-redshift-clustersubnetgroup.json",
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
-    "aws-redshift-eventsubscription.json",
+    "aws-redshift-integration.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
@@ -623,24 +765,38 @@ cached: list[str] = [
     "aws-route53-hostedzone.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
+    "aws-route53resolver-firewalldomainlist.json",
+    "aws-route53resolver-firewallrulegroup.json",
+    "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-s3-accesspoint.json",
+    "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-sagemaker-pipeline.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
     "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
+    "aws-securityhub-automationrule.json",
+    "aws-securityhub-delegatedadmin.json",
+    "aws-securityhub-hub.json",
+    "aws-securityhub-insight.json",
+    "aws-securityhub-organizationconfiguration.json",
+    "aws-securityhub-productsubscription.json",
+    "aws-securityhub-securitycontrol.json",
+    "aws-securityhub-standard.json",
     "aws-servicediscovery-httpnamespace.json",
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
     "aws-servicediscovery-service.json",
+    "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
     "aws-sns-topicpolicy.json",
@@ -648,6 +804,7 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
+    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
@@ -661,6 +818,10 @@ cached: list[str] = [
     "aws-synthetics-canary.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
+    "aws-wafv2-ipset.json",
+    "aws-wafv2-loggingconfiguration.json",
+    "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
